( cd usr/share/lynx/lynx_help ; rm -rf COPYHEADER )
( cd usr/share/lynx/lynx_help ; ln -sf ../lynx_doc/COPYHEADER COPYHEADER )
( cd usr/share/lynx/lynx_help ; rm -rf COPYING )
( cd usr/share/lynx/lynx_help ; ln -sf ../lynx_doc/COPYING COPYING )
( cd usr/doc/lynx-2.8.6rel.5 ; rm -rf lynx_doc )
( cd usr/doc/lynx-2.8.6rel.5 ; ln -sf /usr/share/lynx/lynx_doc lynx_doc )
( cd usr/doc/lynx-2.8.6rel.5 ; rm -rf lynx_help )
( cd usr/doc/lynx-2.8.6rel.5 ; ln -sf /usr/share/lynx/lynx_help lynx_help )
